#!/usr/bin/python -u
#
# Those are the autogenerated Python bindings for libvir.
# Check python/generator.py in the source distribution of libvir
# to find out more about the generation process
#
import libvirmod
import types

#
# Functions from module libvir
#

def open(name):
    """This function should be called first to get a connection to
       the Hypervisor and xen store """
    ret = libvirmod.virConnectOpen(name)
    return virConnect(_obj=ret)

def openReadOnly(name):
    """This function should be called first to get a read-only
       connection to the xen store. The set of APIs usable are
       then restricted. """
    ret = libvirmod.virConnectOpenReadOnly(name)
    return virConnect(_obj=ret)

class virDomain:
    def __init__(self, _obj=None):
        if _obj != None:self._o = _obj;return
        self._o = None

    def __del__(self):
        if self._o != None:
            libvirmod.virDomainFree(self._o)
        self._o = None

    #
    # virDomain functions from module libvir
    #

    def destroy(self):
        """Destroy the domain object. The running instance is shutdown
           if not down already and all resources used by it are given
           back to the hypervisor. The data structure is freed and
           should not be used thereafter if the call does not return
           an error. This function requires priviledged access to the
           hypervisor. """
        ret = libvirmod.virDomainDestroy(self._o)
        return ret

    def iD(self):
        """Get the hypervisor ID number for the domain """
        ret = libvirmod.virDomainGetID(self._o)
        return ret

    def maxMemory(self):
        """Retrieve the maximum amount of physical memory allocated to
           a domain. If domain is None, then this get the amount of
           memory reserved to Domain0 i.e. the domain where the
           application runs. """
        ret = libvirmod.virDomainGetMaxMemory(self._o)
        return ret

    def name(self):
        """Get the public name for that domain """
        ret = libvirmod.virDomainGetName(self._o)
        return ret

    def oSType(self):
        """Get the type of domain operation system. """
        ret = libvirmod.virDomainGetOSType(self._o)
        return ret

    def resume(self):
        """Resume an suspended domain, the process is restarted from
           the state where it was frozen by calling
           virSuspendDomain(). This function requires priviledged
           access to the hypervisor. """
        ret = libvirmod.virDomainResume(self._o)
        return ret

    def setMaxMemory(self, memory):
        """Dynamically change the maximum amount of physical memory
           allocated to a domain. If domain is None, then this change
           the amount of memory reserved to Domain0 i.e. the domain
           where the application runs. This function requires
           priviledged access to the hypervisor. """
        ret = libvirmod.virDomainSetMaxMemory(self._o, memory)
        return ret

    def shutdown(self):
        """Shutdown a domain, the domain object is still usable there
           after but the domain OS is being stopped.  TODO: should we
           add an option for reboot, knowing it may not be doable in
           the general case ? """
        ret = libvirmod.virDomainShutdown(self._o)
        return ret

    def suspend(self):
        """Suspends an active domain, the process is frozen without
           further access to CPU resources and I/O but the memory
           used by the domain at the hypervisor level will stay
           allocated. Use virDomainResume() to reactivate the domain.
           This function requires priviledged access to the
           hypervisor. """
        ret = libvirmod.virDomainSuspend(self._o)
        return ret

    def xMLDesc(self, flags):
        """Provide an XML description of the domain. NOTE: this API is
           subject to changes. """
        ret = libvirmod.virDomainGetXMLDesc(self._o, flags)
        return ret

class virConnect:
    def __init__(self, _obj=None):
        if _obj != None:self._o = _obj;return
        self._o = None

    def __del__(self):
        if self._o != None:
            libvirmod.virConnectClose(self._o)
        self._o = None

    #
    # virConnect functions from module libvir
    #

    def createLinux(self, kernel_path, initrd_path, cmdline, memory, flags):
        """Launch a new Linux guest domain, unimplemented yet, API to
           be defined. This would function requires priviledged
           access to the hypervisor. """
        ret = libvirmod.virDomainCreateLinux(self._o, kernel_path, initrd_path, cmdline, memory, flags)
        __tmp = virDomain(_obj=ret)
        return __tmp

    def getType(self):
        """Get the name of the Hypervisor software used. """
        ret = libvirmod.virConnectGetType(self._o)
        return ret

    def lookupByID(self, id):
        """Try to find a domain based on the hypervisor ID number """
        ret = libvirmod.virDomainLookupByID(self._o, id)
        __tmp = virDomain(_obj=ret)
        return __tmp

    def lookupByName(self, name):
        """Try to lookup a domain on the given hypervisor based on its
           name. """
        ret = libvirmod.virDomainLookupByName(self._o, name)
        __tmp = virDomain(_obj=ret)
        return __tmp

    def numOfDomains(self):
        """Provides the number of active domains. """
        ret = libvirmod.virConnectNumOfDomains(self._o)
        return ret

# virDomainCreateFlags
VIR_DOMAIN_NONE = 0

# virDomainState
VIR_DOMAIN_NOSTATE = 0
VIR_DOMAIN_RUNNING = 1
VIR_DOMAIN_BLOCKED = 2
VIR_DOMAIN_PAUSED = 3
VIR_DOMAIN_SHUTDOWN = 4
VIR_DOMAIN_SHUTOFF = 5

